"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.augmentHostWithResources = void 0;
const paths_1 = require("@ngtools/webpack/src/ivy/paths");
const node_fs_1 = require("node:fs");
const ts = require("typescript");
const ng_1 = require("./authoring/ng");
function augmentHostWithResources(host, transform, options = {}) {
    const resourceHost = host;
    const baseGetSourceFile = resourceHost.getSourceFile.bind(resourceHost);
    if (options.supportNgFormat) {
        resourceHost.getSourceFile = (fileName, languageVersionOrOptions, onError, ...parameters) => {
            if (fileName.includes('.ng')) {
                const contents = (0, node_fs_1.readFileSync)(fileName.replace('.ng.ts', '.ng'), 'utf-8');
                const source = (0, ng_1.processNgFile)(fileName, contents, options.isProd);
                return ts.createSourceFile(fileName, source, languageVersionOrOptions, onError, ...parameters);
            }
            return baseGetSourceFile.call(resourceHost, fileName, languageVersionOrOptions, onError, ...parameters);
        };
    }
    resourceHost.readResource = function (fileName) {
        const filePath = (0, paths_1.normalizePath)(fileName);
        const content = this.readFile(filePath);
        if (content === undefined) {
            throw new Error('Unable to locate component resource: ' + fileName);
        }
        return content;
    };
    resourceHost.transformResource = async function (data, context) {
        // Only style resources are supported currently
        if (context.type !== 'style') {
            return null;
        }
        if (options.inlineStylesExtension) {
            // Resource file only exists for external stylesheets
            const filename = context.resourceFile ??
                `${context.containingFile.replace(/\.ts$/, `.${options?.inlineStylesExtension}`)}`;
            let stylesheetResult;
            try {
                stylesheetResult = await transform(data, `${filename}?direct`);
            }
            catch (e) {
                console.error(`${e}`);
            }
            return { content: stylesheetResult?.code || '' };
        }
        return null;
    };
}
exports.augmentHostWithResources = augmentHostWithResources;
//# sourceMappingURL=host.js.map